@@ -226,7 +226,7 @@ class AugmentationDataLoaderXY(DataLoader2):
     ) -> None:
         reading_service = None
         if threads is not None:
-            reading_service = MultiProcessingReadingService(num_workers=0, main_prefetch_cnt=10, worker_prefetch_cnt=10)
+            reading_service = MultiProcessingReadingService(num_workers=0)
         super().__init__(datapipe, datapipe_adapter_fn, reading_service)
         self.length = len(datapipe)
 
