@@ -34,7 +34,10 @@ class DataAugmentation:
     def augmentByConfig(self, X, Y, config, index=None):
         X = np.expand_dims(X, axis=0)
         Y = np.expand_dims(Y, axis=0)
-
+        
+        return self.augmentBatchesByConfig(X, Y, config, index)
+    
+    def augmentBatchesByConfig(self, X, Y, config, index=None):
         for c in config:
             X, Y = self.loadFromConfig(c, X, Y, self.splitName, index)
 
