@@ -34,9 +34,7 @@ class DataSet:
             return self.y
         if index == 2:
             raise StopIteration
-        raise TypeError(
-            "Datset can only be split in x and y, try to get index %i" % (index)
-        )
+        raise TypeError("Datset can only be split in x and y, try to get index %i" % (index))
 
 
 class DataSetContinous(ValidDataset):
@@ -69,9 +67,10 @@ class DataSetContinous(ValidDataset):
 
     def getFunction(self):
         if self.function is None:
-            self.function = self.batchFunction(
-                recordWise=self.recordWise, augmentation=self.augmentation
-            )
+            if callable(self.batchFunction):
+                self.function = self.batchFunction(recordWise=self.recordWise, augmentation=self.augmentation)
+            else:
+                self.function = iter(self.batchFunction)
         return self.function
 
     def nonContinous(self):
@@ -104,6 +103,12 @@ class DataSetContinous(ValidDataset):
         return batch
 
 
+class TrainingSetLoader:
+    def __init__(self, trainingData=None, validationData=None):
+        self.trainingData: DataSet = trainingData
+        self.validationData: DataSet = validationData
+
+
 class TrainingSet:
     def __init__(
         self,
